@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -322,6 +322,22 @@ collection<C>::collection(const collection<C>& other)
     ++data_.query->useCount;
 }
 
+template <class C>
+collection<C>::collection(collection<C>&& other) noexcept
+  : session_(other.session_),
+    type_(other.type_),
+    data_(other.data_),
+    manualModeInsertions_(std::move(other.manualModeInsertions_)),
+    manualModeRemovals_(std::move(other.manualModeRemovals_))
+{
+  other.session_ = nullptr;
+  other.type_ = RelationCollection;
+  other.data_.relation.sql = nullptr;
+  other.data_.relation.dbo = nullptr;
+  other.data_.relation.setInfo = nullptr;
+  other.data_.relation.activity = nullptr;
+}
+
 template <class C>
 void collection<C>::releaseQuery()
 {
@@ -339,19 +355,47 @@ void collection<C>::releaseQuery()
 template <class C>
 collection<C>& collection<C>::operator=(const collection<C>& other)
 {
-  if (type_ == RelationCollection)
-    delete data_.relation.activity;
-  else
-    releaseQuery();
+  if (this != &other) {
+    if (type_ == RelationCollection)
+      delete data_.relation.activity;
+    else
+      releaseQuery();
 
-  session_ = other.session_;
-  type_ = other.type_;
-  data_ = other.data_;
-  
-  if (type_ == RelationCollection)
-    data_.relation.activity = nullptr;
-  else
-    ++data_.query->useCount;
+    session_ = other.session_;
+    type_ = other.type_;
+    data_ = other.data_;
+
+    if (type_ == RelationCollection)
+      data_.relation.activity = nullptr;
+    else
+      ++data_.query->useCount;
+  }
+
+  return *this;
+}
+
+template <class C>
+collection<C>& collection<C>::operator=(collection<C>&& other) noexcept
+{
+  if (this != &other) {
+    if (type_ == RelationCollection)
+      delete data_.relation.activity;
+    else
+      releaseQuery();
+
+    session_ = other.session_;
+    type_ = other.type_;
+    data_ = other.data_;
+    manualModeInsertions_ = std::move(other.manualModeInsertions_);
+    manualModeRemovals_ = std::move(other.manualModeRemovals_);
+
+    other.session_ = nullptr;
+    other.type_ = RelationCollection;
+    other.data_.relation.sql = nullptr;
+    other.data_.relation.dbo = nullptr;
+    other.data_.relation.setInfo = nullptr;
+    other.data_.relation.activity = nullptr;
+  }
 
   return *this;
 }
