@@ -4,7 +4,7 @@
 #include <Wt/WText.h>
 
 SAMPLE_BEGIN(SpinBox)
-auto container = Wt::cpp14::make_unique<Wt::WContainerWidget>();
+auto container = std::make_unique<Wt::WContainerWidget>();
 container->addStyleClass("form-group");
 
 Wt::WLabel *label = container->addNew<Wt::WLabel>("Enter a number (0 - 100):");
